# x-IMU3-CSV

[![Tags](https://img.shields.io/github/v/tag/xioTechnologies/x-IMU3-CSV.svg)](https://github.com/xioTechnologies/x-IMU3-CSV/tags/)
[![Build](https://img.shields.io/github/actions/workflow/status/xioTechnologies/x-IMU3-CSV/main.yml?branch=main)](https://github.com/xioTechnologies/x-IMU3-CSV/actions/workflows/main.yml)
[![Pypi](https://img.shields.io/pypi/v/ximu3csv.svg)](https://pypi.org/project/ximu3csv/)
[![Python](https://img.shields.io/pypi/pyversions/ximu3csv.svg)](https://pypi.org/project/ximu3csv/)
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
